@@ -79,6 +79,8 @@ class TestBinomialClass(unittest.TestCase):
         self.binomial.replace_stats_with_data()
         self.assertEqual(round(self.binomial.pdf(5), 5), 0.05439)
         self.assertEqual(round(self.binomial.pdf(3), 5), 0.00472)
+        self.binomial.plot_bar()
+        self.binomial.plot_bar_pdf()
 
     def test_add(self):
         binomial_one = Binomial(.4, 20)
